<?php

namespace FiloBlu\Newsletter\Model\ResourceModel;

class Subscriber extends \Magento\Newsletter\Model\ResourceModel\Subscriber {

    protected $_multiDomainHelper;
    protected $_storeManager;

    public function __construct(
    \Magento\Framework\Model\ResourceModel\Db\Context $context, \Magento\Framework\Stdlib\DateTime\DateTime $date, \Magento\Framework\Math\Random $mathRandom, \FiloBlu\MultiDomain\Helper\Data $multiDomainHelper, \Magento\Store\Model\StoreManagerInterface $storeManager
    ) {
        $this->_multiDomainHelper = $multiDomainHelper;
        $this->_storeManager = $storeManager;
        parent::__construct($context, $date, $mathRandom);
    }

    /**
     * Load subscriber from DB by email
     *
     * @param string $subscriberEmail
     * @return array
     */
    public function loadByEmail($subscriberEmail,$groupName = null) {

        if (!$groupName) {
            $currentGroup = $this->_multiDomainHelper->getCurrentGroup();
        }
        else {
            $currentGroup = $groupName;
        }
        

        if ($currentGroup) {
            $select = $this->connection->select()->from($this->getMainTable())->where('subscriber_email=:subscriber_email');

            $results = $this->connection->fetchAssoc($select, ['subscriber_email' => $subscriberEmail]);

            $result = false;

            foreach ($results as $r) {

                $subscriberStoreId = $r['store_id'];
                $subscriberWebsiteCode = $this->_storeManager->getStore($subscriberStoreId)->getWebsite()->getCode();
                $subscriberGroup = $this->_multiDomainHelper->getCurrentGroup($subscriberWebsiteCode);

                if ($currentGroup == $subscriberGroup) {
                    $result = $r;
                    break;
                }
            }

            if (!$result) {
                return [];
            }

            return $result;
        } else {
            return parent::loadByEmail($subscriberEmail);
        }
    }

    /**
     * Load subscriber by customer
     *
     * @param \Magento\Customer\Api\Data\CustomerInterface $customer
     * @return array
     */
    public function loadByCustomerData(\Magento\Customer\Api\Data\CustomerInterface $customer) {
        $currentGroup = $this->_multiDomainHelper->getCurrentGroup();

        if ($currentGroup) {
            $select = $this->connection->select()->from($this->getMainTable())->where('customer_id=:customer_id');

            $result = $this->connection->fetchRow($select, ['customer_id' => $customer->getId()]);

            if ($result) {
                return $result;
            }

            $select = $this->connection->select()->from($this->getMainTable())->where('subscriber_email=:subscriber_email');

            $results = $this->connection->fetchAssoc($select, ['subscriber_email' => $customer->getEmail()]);

            $result = false;

            foreach ($results as $r) {

                $subscriberStoreId = $r['store_id'];
                $subscriberWebsiteCode = $this->_storeManager->getStore($subscriberStoreId)->getWebsite()->getCode();
                $subscriberGroup = $this->_multiDomainHelper->getCurrentGroup($subscriberWebsiteCode);

                if ($currentGroup == $subscriberGroup) {
                    $result = $r;
                    break;
                }
            }

            if (!$result) {
                return [];
            }

            return $result;
        } else {
            return parent::loadByCustomerData($customer);
        }
    }

}
